@@ -30,24 +30,21 @@ def arg_parse(config_file):
 
     if args.check:
         parse_config(config_file)
-        check_upload_file(config_file['filepath'])
+        check_upload_file(upload_file_path)
         exit(0)
     elif args.upload:
         parse_config(config_file)
-        # TODO: pass upload_file_path to check_upload_file
-        check_upload_file(config_file['filepath'])
+        validate(radarType, version_name)
+        check_upload_file(upload_file_path)
 
-        version_dir_to_upload= os.path.join(config_file['filepath'], version_name)
-        zipped_file_path = os.path.join(config_file['filepath'], version_name + '.zip')
+        version_dir_to_upload= os.path.join(upload_file_path, version_name)
+        zipped_file_path = os.path.join(upload_file_path, version_name + '.zip')
 
         print('version_dir_to_upload: ', version_dir_to_upload)
         print('zipped_file_path: ', zipped_file_path)
 
-        validate(radarType, version_name)
         create_zip(zipped_file_path, version_name)
-        # TODO:pass upload_file_path to push_software
         push_software(config_file, zipped_file_path, radarType, version_name)
-        # TODO:logging or sending log to server
         remove_zip(zipped_file_path)
     else:
         parser.print_help()
